@@ -4,7 +4,9 @@ use namespace::clean;
 
 with qw(
     ZooKeeper::XT::Role::CheckACLs
+    ZooKeeper::XT::Role::CheckCreate
     ZooKeeper::XT::Role::CheckSessionEvents
+    ZooKeeper::XT::Role::CheckSet
     ZooKeeper::XT::Role::CheckTransactions
 );
 
